summaryrefslogtreecommitdiff
path: root/tcwg-generate-source-cache.sh
diff options
context:
space:
mode:
authorMaxim Kuvyrkov <maxim.kuvyrkov@linaro.org>2018-10-02 11:01:23 +0000
committerMaxim Kuvyrkov <maxim.kuvyrkov@linaro.org>2018-10-02 17:36:54 +0000
commitda4635750634be5351b2d38fd7a0fd11489c969d (patch)
tree1b0fb633af1cf8b42ae8a5a8a41c8c845358db83 /tcwg-generate-source-cache.sh
parente145ce1da3991f7584fd412030037079375c1936 (diff)
tcwg-generate-source-cache.sh: Add LLVM monorepo to "misc"
... and use linux "stable" git as reference. This repo contains various stable branches in addition to Linus's tree. Remove linux-next remote since it contains only a small delta compared to Linus's tree. Change-Id: I4c7eecadd9738a341247df4e234d06f86f4a12c1
Diffstat (limited to 'tcwg-generate-source-cache.sh')
-rwxr-xr-xtcwg-generate-source-cache.sh26
1 files changed, 14 insertions, 12 deletions
diff --git a/tcwg-generate-source-cache.sh b/tcwg-generate-source-cache.sh
index 1acd56fe..7d3b0120 100755
--- a/tcwg-generate-source-cache.sh
+++ b/tcwg-generate-source-cache.sh
@@ -126,18 +126,20 @@ generate_misc_files ()
tar xf $HOME/public_html/infrastructure/FM000-KT-00035-r9p5-41rel0.tgz -C $snapshots_dir
chmod -R ugo+rx $snapshots_dir/Foundation_Platformpkg
- # Clone the Linux kernel if not already
- # present. Subsequent calls will update it.
- linux_git=$snapshots_dir/linux.git
- if [ ! -d ${linux_git} ]; then
- git clone git://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux.git ${linux_git}
- fi
-
- # Add a 'next' remote for linux-next, if not already present
- count=$(git -C ${linux_git} remote | grep -c next || true)
- if [ $count -eq 0 ]; then
- git -C ${linux_git} remote add next git://git.kernel.org/pub/scm/linux/kernel/git/next/linux-next.git
- fi
+ # Clone the Linux kernel and LLVM monorepo.
+ # Subsequent calls will update it.
+ repos=(
+ git://git.kernel.org/pub/scm/linux/kernel/git/stable/linux.git
+ https://github.com/llvm-project/llvm-project-20170507.git
+ )
+ for repo in "${repos[@]}"; do
+ dir=$(basename $repo)
+ dir=$snapshots_dir/$dir
+ if [ ! -d $dir/.git ]; then
+ rm -rf $dir
+ git clone --no-checkout $repo $dir
+ fi
+ done
}
update_git_repos () {